==> nextcloud-13.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/theming/l10n/es_MX.js <==
OC.L10N.register(
    "theming",
    {
    "Loading preview…" : "Cargando vista previa...",
    "Saved" : "Guardado",
    "Admin" : "Administración",
    "a safe home for all your data" : "un lugar seguro para todos tus datos",
    "Name cannot be empty" : "El nombre no puede estar en blanco",
    "The given name is too long" : "El nombre dado es demasiado largo",
    "The given web address is too long" : "La dirección web dada es demasiado larga",
    "The given slogan is too long" : "El lema dado es demasiado largo",
    "The given color is invalid" : "El color dado es inválido",
    "The file was uploaded" : "El archivo fue cargado",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "El archivo cargado excede el valor establecido en la directiva upload_max_filesize en el archivo php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "El archivo cargado excede el valor especificado de la directiva MAX_FILE_SIZE en la forma de HTML",
    "The file was only partially uploaded" : "El archivo sólo fue cargado parcialmente",
    "No file was uploaded" : "No se cargó el archivo",
    "Missing a temporary folder" : "Falta una carpeta temporal",
    "Could not write file to disk" : "No fue posible escribir a disco",
    "A PHP extension stopped the file upload" : "Una extensión de PHP detuvo la carga del archivo",
    "No file uploaded" : "No hay archivos cargados",
    "Unsupported image type" : "Tipo de imagen no soportado",
    "Theming" : "Tematizar",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "El tematizar hace posible personalizar facilmente la manera en que se ve tu instancia y clientes soportados. Esto será visible para todos los usuarios. ",
    "Name" : "Nombre",
    "Reset to default" : "Restablecer al predeterminado",
    "Web address" : "Dirección web",
    "Web address https://…" : "Dirección web https://...",
    "Slogan" : "Lema",
    "Color" : "Color",
    "Logo" : "Logotipo",
    "Upload new logo" : "Cargar nuevo logotipo",
    "Login image" : "Imágen de inicio de sesión",
    "Upload new login background" : "Cargar nueva imagen de fondo para inicio de sesión",
    "Remove background image" : "Eliminar imagen de fondo",
    "Install the Imagemagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Instala la extensión Imagemagick de PHP con soporte a imagenes SVG para generar los favicons en automático con base en el logotipo cargado y el color.",
    "You are already using a custom theme" : "Ya estás usando un tema personalizado",
    "reset to default" : "restaurar a predeterminado",
    "There is no error, the file uploaded with success" : "No hay errores, el archivo se cargó exitosamente",
    "The uploaded file was only partially uploaded" : "La carga del archivo solo se realizó parcialmente",
    "Failed to write file to disk." : "Se presentó una falla al escribir el archivo en el disco. ",
    "A PHP extension stopped the file upload." : "Una extensión de PHP detuvo la carga del archivo. "
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-13.0.5-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/theming/l10n/es_MX.js <==
OC.L10N.register(
    "theming",
    {
    "Loading preview…" : "Cargando vista previa...",
    "Saved" : "Guardado",
    "Admin" : "Administración",
    "a safe home for all your data" : "un lugar seguro para todos tus datos",
    "Name cannot be empty" : "El nombre no puede estar en blanco",
    "The given name is too long" : "El nombre dado es demasiado largo",
    "The given web address is too long" : "La dirección web dada es demasiado larga",
    "The given legal notice address is too long" : "La dirección del aviso legal es demasiado larga",
    "The given privacy policy address is too long" : "La dirección de la política de privacidad dada es demasiado larga",
    "The given slogan is too long" : "El lema dado es demasiado largo",
    "The given color is invalid" : "El color dado es inválido",
    "The file was uploaded" : "El archivo fue cargado",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "El archivo cargado excede el valor establecido en la directiva upload_max_filesize en el archivo php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "El archivo cargado excede el valor especificado de la directiva MAX_FILE_SIZE en la forma de HTML",
    "The file was only partially uploaded" : "El archivo sólo fue cargado parcialmente",
    "No file was uploaded" : "No se cargó el archivo",
    "Missing a temporary folder" : "Falta una carpeta temporal",
    "Could not write file to disk" : "No fue posible escribir a disco",
    "A PHP extension stopped the file upload" : "Una extensión de PHP detuvo la carga del archivo",
    "No file uploaded" : "No hay archivos cargados",
    "Unsupported image type" : "Tipo de imagen no soportado",
    "You are already using a custom theme. Theming app settings might be overwritten by that." : "Ya te encuentras usando un tema personalizado. La aplicación de Temas puede estar siendo sobreescrita por él.",
    "Theming" : "Tematizar",
    "Legal notice" : "Aviso legal",
    "Privacy policy" : "Política de privacidad",
    "Adjust the Nextcloud theme" : "Ajusta el tema de Nextcloud",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "El tematizar hace posible personalizar facilmente la manera en que se ve tu instancia y clientes soportados. Esto será visible para todos los usuarios. ",
    "Name" : "Nombre",
    "Reset to default" : "Restablecer al predeterminado",
    "Web link" : "Enlace web",
    "https://…" : "https://…",
    "Slogan" : "Lema",
    "Color" : "Color",
    "Logo" : "Logotipo",
    "Upload new logo" : "Cargar nuevo logotipo",
    "Login image" : "Imágen de inicio de sesión",
    "Upload new login background" : "Cargar nueva imagen de fondo para inicio de sesión",
    "Remove background image" : "Eliminar imagen de fondo",
    "Advanced options" : "Opciones avanzadas",
    "Legal notice link" : "Enlace al aviso legal",
    "Privacy policy link" : "Liga a la política de privacidad",
    "Header logo" : "Logo del encabezado",
    "Upload new header logo" : "Cargar un nuevo logotipo del encabezado",
    "Favicon" : "Favicon",
    "Upload new favicon" : "Cargar un nuevo favicon",
    "Install the Imagemagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Instala la extensión Imagemagick de PHP con soporte a imagenes SVG para generar los favicons en automático con base en el logotipo cargado y el color.",
    "You are already using a custom theme" : "Ya estás usando un tema personalizado",
    "reset to default" : "restaurar a predeterminado",
    "Web address" : "Dirección web",
    "Web address https://…" : "Dirección web https://...",
    "There is no error, the file uploaded with success" : "No hay errores, el archivo se cargó exitosamente",
    "The uploaded file was only partially uploaded" : "La carga del archivo solo se realizó parcialmente",
    "Failed to write file to disk." : "Se presentó una falla al escribir el archivo en el disco. ",
    "A PHP extension stopped the file upload." : "Una extensión de PHP detuvo la carga del archivo. "
},
"nplurals=2; plural=(n != 1);");
